@@ -1,5 +1,7 @@
 from __future__ import absolute_import
 from __future__ import print_function
+
+import json
 import os
 import sys
 import tempfile
@@ -9,61 +11,20 @@ from PIL import Image
 
 import numpy as np
 from aetros.Trainer import Trainer
-from aetros.logger import GeneralLogger
 from aetros.keras_model_utils import ensure_dir
 from aetros.backend import JobBackend
 
-def create_simple(id, last_weights=False):
-    job_backend = JobBackend()
-    job_backend.load(id)
-    job_model = job_backend.get_job_model()
-
-    if last_weights:
-        weights_path = job_model.get_weights_filepath_latest()
-    else:
-        weights_path = job_model.get_weights_filepath_best()
-
-    if not os.path.exists(weights_path) or os.path.getsize(weights_path) == 0:
-        weight_url = job_backend.get_best_weight_url(id)
-        if not weight_url:
-            raise Exception("No weights available for this job.")
-
-        print(("Download weights %s to %s .." % (weight_url, weights_path)))
-        ensure_dir(os.path.dirname(weights_path))
-
-        f = open(weights_path, 'wb')
-        f.write(urllib.urlopen(weight_url).read())
-        f.close()
-
-    model.job_prepare(job_model)
-
-    general_logger = GeneralLogger(job_backend=job_backend)
-    trainer = Trainer(job_backend, general_logger)
-
-    job_model.set_input_shape(trainer)
-
-    model = job_model.get_built_model(trainer)
-
-    from aetros.keras import load_weights
-    load_weights(model, weights_path)
-
-    return job_model, model
-
 
 class JobModel:
     """
     :type job : dict
     """
-    def __init__(self, job):
+    def __init__(self, id, job, storage_dir):
+        self.id = id
         self.job = job
-
-    @property
-    def model_id(self):
-        return self.job['modelId']
-
-    @property
-    def id(self):
-        return self.job['id']
+        self.storage_dir = storage_dir
+        self._layers = None
+        self._datasets = None
 
     @property
     def config(self):
@@ -71,13 +32,17 @@ class JobModel:
 
     @property
     def model_settings(self):
-        return self.config['settings']
+        return self.job['modelSettings']
+
+    @property
+    def insights_enabled(self):
+        return self.config['insights']
 
     def get_model_node(self, name):
-        if not isinstance(self.job['config']['layer'], list):
+        if not isinstance(self.layers, list):
             return None
 
-        for nodes in self.job['config']['layer']:
+        for nodes in self.layers:
             if isinstance(nodes, list):
                 for node in nodes:
                     if 'varName' in node and node['varName'] == name:
@@ -88,36 +53,36 @@ class JobModel:
         return None
 
     def get_batch_size(self):
-        return self.job['config']['settings']['batchSize']
+        return self.job['config']['batchSize']
 
     def get_model_h5_path(self):
-        return os.getcwd() + '/aetros-cli-data/models/%s/%s/model.h5' % (self.model_id, self.id)
+        return os.getcwd() + '/aetros/model.h5'
+
+    def get_layers_path(self):
+        return os.getcwd() + '/aetros/layer.json'
 
     def get_dataset_dir(self):
-        return os.getcwd() + '/aetros-cli-data/models/%s/%s/datasets' % (self.model_id, self.id)
-
-    def get_base_dir(self):
-        return os.getcwd() + '/aetros-cli-data/models/%s/%s' % (self.model_id, self.id)
+        return os.getcwd() + '/aetros/dataset/'
 
     def get_dataset_downloads_dir(self, dataset):
-        return os.getcwd() + '/aetros-cli-data/datasets/%s/datasets_downloads' % (dataset['id'],)
+        return self.storage_dir + '/aetros/dataset/%s/datasets_downloads' % (dataset['id'],)
 
     def get_weights_filepath_latest(self):
-        return os.getcwd() + '/aetros-cli-data/weights/%s/latest.hdf5' % (self.id,)
+        return os.getcwd() + '/aetros/weights_latest.hdf5'
 
     def get_weights_filepath_best(self):
-        return os.getcwd() + '/aetros-cli-data/weights/%s/best.hdf5' % (self.id,)
+        return os.getcwd() + '/aetros/weights_best.hdf5'
 
     def get_input_names(self):
         names = []
-        for node in self.job['config']['layer'][0]:
+        for node in self.layer[0]:
             names.append(node['varName'])
 
         return names
 
     def get_input_dataset_names(self):
         names = []
-        for node in self.job['config']['layer'][0]:
+        for node in self.layers[0]:
             names.append(node['datasetId'])
 
         return names
@@ -126,12 +91,12 @@ class JobModel:
 
         trainer.input_shape = {}
 
-        for node in self.job['config']['layer'][0]:
+        for node in self.layers[0]:
             size = (int(node['width']), (node['height']))
             if node['inputType'] == 'image':
-                shape = (1, size[0], size[1])
+                shape = (size[0], size[1], 1)
             elif node['inputType'] == 'image_rgb':
-                shape = (3, size[0], size[1])
+                shape = (size[0], size[1], 3)
             else:
                 shape = (size[0] * size[1],)
 
@@ -141,6 +106,12 @@ class JobModel:
                 # older models
                 trainer.input_shape = shape
 
+    def is_python_model(self):
+        return 'fromCode' in self.job['config'] and self.job['config']['fromCode']
+
+    def is_keras_model(self):
+        return 'fromCode' not in self.job['config'] or not self.job['config']['fromCode']
+
     def get_built_model(self, trainer):
 
         if 'fromCode' in self.job['config'] and self.job['config']['fromCode']:
@@ -243,17 +214,45 @@ class JobModel:
 
     def get_model_provider(self):
 
-        sys.path.append(self.get_base_dir())
+        sys.path.append('./')
 
-        import model_provider
-        print("Imported model_provider in %s " % (self.get_base_dir() + '/model_provider.py',))
+        model = __import__('model', '')
+        print("Imported model script from %s " % (os.path.abspath('./model.py'),))
         sys.path.pop()
 
-        return model_provider
+        return model
+    
+    @property
+    def layers(self):
+        if self._layers is None:
+            with open(self.get_layers_path(), 'r') as f:
+                self._layers = json.loads(f.read())
+
+        return self._layers
+
+    @property
+    def datasets(self):
+        if self._datasets is None:
+            self._datasets = {}
+
+            def read_dataset(id):
+                with open(self.get_dataset_dir() + id + '.json', 'r') as f:
+                    self._datasets[id] = json.loads(f.read())
+
+            for owner in os.listdir(self.get_dataset_dir()):
+                path = self.get_dataset_dir() + owner + '/dataset/'
+                for name in os.listdir(path):
+                    if name.endswith('.json'):
+                        read_dataset(owner + '/dataset/' + name[:-len('.json')])
+
+                    if os.path.isdir(path + name):
+                        for sub in os.listdir(path + name):
+                            if sub.endswith('.json'):
+                                read_dataset(owner + '/dataset/' + name + '/' + sub[:-len('.json')])
+
+        return self._datasets
 
     def get_datasets(self, trainer):
-        datasets_dir = self.get_dataset_dir()
-
         datasets = {}
 
         from aetros.utils import get_option
@@ -261,17 +260,20 @@ class JobModel:
 
         # load placeholder, auto data
         config = self.job['config']
-        for layer in config['layer'][0]:
+        for layer in self.layers[0]:
             if 'datasetId' in layer and layer['datasetId']:
 
-                dataset = config['datasets'][layer['datasetId']]
+                if layer['datasetId'] not in self.datasets:
+                    raise Exception('Dataset %s not found in datasets %s' % (layer['datasetId'], json.dumps(self.datasets.keys())))
+
+                dataset = self.datasets[layer['datasetId']]
                 if not dataset:
                     raise Exception('Dataset of id %s does not exists. Available %s' % (
-                    layer['datasetId'], ','.join(list(config['datasets'].keys()))))
+                    layer['datasetId'], ','.join(list(self.datasets.keys()))))
 
                 if dataset['type'] == 'images_upload' or dataset['type'] == 'images_search':
 
-                    connected_to_layer = self.get_connected_layer(config['layer'], layer)
+                    connected_to_layer = self.get_connected_layer(self.layers, layer)
                     if connected_to_layer is None:
                         # this input is not in use, so we dont need to calculate its dataset
                         continue
@@ -288,11 +290,11 @@ class JobModel:
                         datasets[layer['datasetId']] = read_images_keras_generator(self, dataset, layer, trainer)
 
                 elif dataset['type'] == 'python':
-                    name = dataset['id'].replace('/', '__')
+                    name = dataset['id']
 
-                    sys.path.append(datasets_dir)
+                    sys.path.append(sys.path.abspath('./aetros/'))
                     data_provider = __import__(name, '')
-                    print("Imported dataset provider in %s " % (datasets_dir + '/' + name + '.py',))
+                    print("Imported dataset provider from %s " % (os.path.abspath('./aetros/' + name + '.py'),))
                     sys.path.pop()
                     import inspect
                     argSpec = inspect.getargspec(data_provider.get_data)
@@ -305,13 +307,11 @@ class JobModel:
         return datasets
 
     def get_dataset_class_label(self, output_layer, prediction):
-        config = self.job['config']
-
         dataset_id = output_layer['datasetId']
-        dataset = config['datasets'][dataset_id]
+        dataset = self.datasets[dataset_id]
         if not dataset:
             raise Exception('Dataset of id %s does not exists. Available %s' % (
-            dataset_id, ','.join(list(config['datasets'].keys()))))
+            dataset_id, ','.join(list(self.datasets.keys()))))
 
         if 'classes' in self.job['info']:
             return self.job['info']['classes'][prediction]
@@ -334,18 +334,18 @@ class JobModel:
 
     def get_first_input_layer(self):
         config = self.job['config']
-        return config['layer'][0][0]
+        return self.layers[0][0]
 
     def get_input_node(self, idx):
         config = self.job['config']
-        return config['layer'][0][idx]
+        return self.layers[0][idx]
 
     def get_first_output_layer(self):
         config = self.job['config']
-        return config['layer'][-1][0]
+        return self.layers[-1][0]
 
     def get_dataset(self, dataset_id):
-        return self.job['config']['datasets'][dataset_id]
+        return self.datasets[dataset_id]
 
     def get_connected_layer(self, layers, to_net):
         connected_to_net = None
