@@ -5,8 +5,6 @@ from __future__ import absolute_import
 import os
 import time
 
-from keras.optimizers import Adadelta, Adam, Adamax, Adagrad, RMSprop, SGD
-
 from aetros.Trainer import is_generator
 from aetros.backend import JobImage
 
@@ -28,6 +26,7 @@ from aetros.utils.image import get_layer_vis_square, get_layer_vis_square_raw, g
 from .keras_model_utils import ensure_dir, get_total_params
 import six
 
+
 # compatibility with keras 1.x
 def image_data_format():
     if hasattr(K, 'image_data_format'):
@@ -71,6 +70,7 @@ class KerasCallback(Callback):
 
         ensure_dir(os.path.dirname(self.filepath_best))
 
+        self.kpi_channel = None
         self.accuracy_channel = None
         self.all_losses = None
         self.loss_channel = None
@@ -81,6 +81,9 @@ class KerasCallback(Callback):
         self.insights_x = None
         self.best_total_accuracy = 0
 
+    def add_insight_layer(self, layer):
+        self.insight_layer.append(layer)
+
     def set_validation_data(self, validation_data, validation_data_size=None):
 
         self.data_validation = validation_data
@@ -132,6 +135,9 @@ class KerasCallback(Callback):
         self.job_backend.set_info('backend', K.backend())
         self.job_backend.set_info('Keras version', keras.__version__)
 
+        if hasattr(K, 'image_dim_ordering'):
+            self.job_backend.set_info('Keras image_data_format', K.image_dim_ordering())
+
         self.job_backend.upload_keras_graph(self.model)
 
         if self.model.optimizer and hasattr(self.model.optimizer, 'get_config'):
@@ -140,10 +146,6 @@ class KerasCallback(Callback):
             for i, v in config.items():
                 self.job_backend.set_info('optimizer.'+str(i), v)
 
-        self.current['epoch'] = 0
-        self.current['started'] = self.start_time
-        self.job_backend.set_system_info('current', self.current)
-
         #compatibility with keras 1.x
         if 'epochs' not in self.params and 'nb_epoch' in self.params:
             self.params['epochs'] = self.params['nb_epoch']
@@ -160,16 +162,23 @@ class KerasCallback(Callback):
             'dtick': 10
         }
 
-        traces = ['validation', 'training']
+        traces = ['training', 'validation']
         if len(self.model.output_layers) > 1:
             traces = []
             for output in self.model.output_layers:
-                traces.append(output.name+'_validation')
                 traces.append(output.name+'_training')
+                traces.append(output.name+'_validation')
 
-        self.accuracy_channel = self.job_backend.create_channel('accuracy', main=True, traces=traces, kpi=True, max_optimization=True, xaxis=xaxis, yaxis=yaxis)
+        is_accuracy_kpi = True if self.job_backend.kpi_channel is None else False
+
+        self.accuracy_channel = self.job_backend.create_channel(
+            'accuracy',
+            main=True, traces=traces, kpi=is_accuracy_kpi, kpiTrace=1,
+            max_optimization=True, xaxis=xaxis, yaxis=yaxis
+        )
         self.loss_channel = self.job_backend.create_loss_channel('loss', xaxis=xaxis)
         self.learning_rate_channel = self.job_backend.create_channel('learning rate', traces=['start', 'end'], xaxis=xaxis)
+
         self.job_backend.progress(0, self.params['epochs'])
         if len(self.model.output_layers) > 1:
             loss_traces = []
@@ -179,8 +188,9 @@ class KerasCallback(Callback):
 
             self.all_losses = self.job_backend.create_channel('All loss', main=True, xaxis=xaxis, traces=loss_traces)
 
-        images = self.build_insight_images()
-        self.job_backend.job_add_insight(0, images, None)
+        if self.force_insights or self.job_model.insights_enabled:
+            images = self.build_insight_images()
+            self.job_backend.job_add_insight(0, images, None)
 
     def on_batch_begin(self, batch, logs={}):
         if 'nb_batches' not in self.current:
@@ -273,7 +283,7 @@ class KerasCallback(Callback):
                 log['epoch'], log['loss'], log.get('acc', 0), log.get('val_loss', 0), total_accuracy_validation, )
             self.general_logger.write(line)
 
-        if self.force_insights or self.job_model.job['insights']:
+        if self.force_insights or self.job_model.config['insights']:
             # Todo, support multiple inputs
             first_input_layer = self.model.input_layers[0]
 
@@ -293,6 +303,8 @@ class KerasCallback(Callback):
         if hasattr(self.model, 'optimizer'):
             config = self.model.optimizer.get_config()
 
+            from keras.optimizers import Adadelta, Adam, Adamax, Adagrad, RMSprop, SGD
+
             if isinstance(self.model.optimizer, Adadelta) or isinstance(self.model.optimizer, Adam) \
                     or isinstance(self.model.optimizer, Adamax) or isinstance(self.model.optimizer, Adagrad)\
                     or isinstance(self.model.optimizer, RMSprop) or isinstance(self.model.optimizer, SGD):
@@ -352,7 +364,6 @@ class KerasCallback(Callback):
 
         layers = self.model.layers + self.insight_layer
 
-
         for layer in layers:
             if isinstance(layer, keras.layers.convolutional.Convolution2D) or isinstance(layer, keras.layers.convolutional.MaxPooling2D):
 
@@ -404,7 +415,6 @@ class KerasCallback(Callback):
                     if Y.size == 1:
                         Y = np.array([Y])
 
-                    node = self.job_model.get_model_node(layer.name)
 
                     image = None
                     if len(Y.shape) > 1:
@@ -414,10 +424,7 @@ class KerasCallback(Callback):
 
                         image = PIL.Image.fromarray(get_layer_vis_square(Y))
                     elif len(Y.shape) == 1:
-                        if node and node['activationFunction'] == 'softmax':
-                            image = self.make_image_from_dense_softmax(Y)
-                        else:
-                            image = self.make_image_from_dense(Y)
+                        image = self.make_image_from_dense(Y)
 
                     if image:
                         images.append(JobImage(layer.name, image))
