@@ -2,6 +2,9 @@ from __future__ import absolute_import
 from __future__ import print_function
 
 import sys
+import logging
+import os
+
 import aetros.const
 
 __version__ = const.__version__
@@ -11,7 +14,10 @@ command_summaries = [
     ['predict', 'Runs a prediction locally'],
     ['upload-weights', 'Uploads weights as new or existing job.'],
     ['prediction-server', 'Spawns a http server that handles incoming data as input and predicts output.'],
-    ['server', 'Spawns a job server that handles jobs managed through AETROS Trainer'],
+    ['server', 'Spawns a job server that handles jobs managed through AETROS Trainer.'],
+    ['run', 'Executes a command on an AETROS server.'],
+    ['api', 'Executes a API call through SSH connection.'],
+    ['push-job', 'Pushes a local job to AETROS Trainer.'],
 ]
 
 def parseopts(args):
@@ -36,11 +42,19 @@ def main(args=None):
     if args is None:
         args = sys.argv[1:]
 
+    cmd_name, cmd_args = parseopts(args)
+    if cmd_name == '--version':
+        print(aetros.const.__version__)
+        sys.exit(0)
+
+    from aetros.commands.ApiCommand import ApiCommand
+    from aetros.commands.PushJobCommand import PushJobCommand
     from aetros.commands.ServerCommand import ServerCommand
     from aetros.commands.UploadWeightsCommand import UploadWeightsCommand
     from aetros.commands.PredictCommand import PredictCommand
     from aetros.commands.PredictionServerCommand import PredictionServerCommand
     from aetros.commands.StartCommand import StartCommand
+    from aetros.commands.RunCommand import RunCommand
 
     commands_dict = {
         'start': StartCommand,
@@ -48,14 +62,31 @@ def main(args=None):
         'upload-weights': UploadWeightsCommand,
         'prediction-server': PredictionServerCommand,
         'server': ServerCommand,
+        'run': RunCommand,
+        'api': ApiCommand,
+        'push-job': PushJobCommand,
     }
-    cmd_name, cmd_args = parseopts(args)
+
+    log_level = 'INFO'
+    if os.getenv('DEBUG') == '1':
+        log_level = 'DEBUG'
+
+    logger = logging.getLogger('aetros-'+cmd_name)
+
+    import coloredlogs
+    coloredlogs.install(level=log_level, logger=logger)
 
     if cmd_name not in commands_dict:
         print(("Command %s not found" % (cmd_name,)))
         sys.exit(1)
 
-    command = commands_dict[cmd_name]()
+    level = 'INFO'
+    if '-v' in args:
+        level = 'DEBUG'
+
+    logger = logging.getLogger('aetros-'+cmd_name)
+    coloredlogs.install(level=level, logger=logger)
+    command = commands_dict[cmd_name](logger)
 
     code = command.main(cmd_args)
     sys.exit(code)
