@@ -2,4 +2,4 @@ import sys
 import aetros
 
 if __name__ == '__main__':
-    sys.exit(aetros.main(sys.argv[1:]))
\ No newline at end of file
+    sys.exit(aetros.main())
\ No newline at end of file
