@@ -1,4 +1,4 @@
-__version__ = '0.9.1'
+__version__ = '0.10.3'
 __prog__ = "aetros"
 
 class bcolors:
@@ -15,6 +15,6 @@ class JOB_STATUS:
     PROGRESS_STATUS_CREATED = 0
     PROGRESS_STATUS_QUEUED = 1
     PROGRESS_STATUS_STARTED = 2
-    PROGRESS_STATUS_ENDED = 3
+    PROGRESS_STATUS_DONE = 3
     PROGRESS_STATUS_ABORTED = 4
     PROGRESS_STATUS_CRASHED = 5
\ No newline at end of file
