@@ -4,10 +4,12 @@ import json
 import os
 
 from aetros.Trainer import is_generator
-from .backend import invalid_json_values
 import six
 from six.moves import range
 
+from aetros.utils import invalid_json_values
+
+
 def ensure_dir(d):
     if not os.path.isdir(d):
         if os.path.isfile(d):  # but a file, so delete it
@@ -91,39 +93,10 @@ def job_start(job_backend, trainer, keras_logger):
     model_provider.train(trainer, model, data_train, data_validation)
 
 
-def job_prepare(job_model):
+def job_prepare(job_backend):
     """
     Setups all necessary folder structure so the network can run with datasets code and model_provider.py.
     :type job_model: JobModel
     """
 
-    path = 'aetros-cli-data/models/%s/%s' % (job_model.model_id, job_model.id)
-    datasets_path = path + '/datasets'
-    config = job_model.config
-
-    ensure_dir(path)
-    ensure_dir(datasets_path)
-
-    if not os.path.isfile(path + '/model_provider.py'):
-        with open(path + '/model_provider.py', 'w+') as f:
-            f.write(config['code'])
-            f.close()
-
-    inputOutputNodes = config['layer'][0] + config['layer'][-1]
-
-    for net in inputOutputNodes:
-        if net['datasetId']:
-            if net['datasetId'] not in config['datasets']:
-                raise Exception('Could not find dataset %s. You probably have no access. Available %s' % (
-                    net['datasetId'], ','.join(list(config['datasets'].keys()))))
-
-            dataset = config['datasets'][net['datasetId']]
-            if dataset['type'] == 'python':
-
-                name = dataset['id'].replace('/', '__')
-                dataset_path = datasets_path + '/' + name + '.py'
-
-                if not os.path.isfile(dataset_path):
-                    with open(dataset_path, 'w+') as f:
-                        f.write(dataset['config']['code'])
-                        f.close()
+    pass
