@@ -1,20 +1,20 @@
 from __future__ import absolute_import
+
 import sys
 import time
 import datetime
 import six
-from threading import Timer
+from threading import Timer, Thread
+
 
 class GeneralLogger(object):
-    def __init__(self, logFD=None, job_backend=None, error=False):
+    def __init__(self, job_backend, logger=None, error=False):
         self.error = error
         self.job_backend = job_backend
         self.buffer = ''
         self.last_timer = None
         self.last_messages = ''
-
-        self.terminal = sys.__stdout__ if error is False else sys.__stderr__
-        self.logFD = logFD
+        self.logger = logger or (sys.__stdout__ if error is False else sys.__stderr__)
 
     def get_time(self):
         ts = time.time()
@@ -29,45 +29,56 @@ class GeneralLogger(object):
         return line
 
     def fileno(self):
-        return sys.__stdout__.fileno() if self.error is False else sys.__stderr__.fileno()
+        return self.logger.fileno()
 
     def flush(self):
-        if self.logFD:
-            self.logFD.flush()
+        self.logger.flush()
+        self.send_buffer()
 
-        self.terminal.flush()
-
-    def send_to_buffer(self):
+    def send_buffer(self):
         self.last_timer = None
 
         if self.buffer:
-            if self.logFD:
-                self.logFD.write(self.buffer)
-
-            if self.job_backend and self.job_backend.running:
+            if self.job_backend:
                 self.job_backend.write_log(self.buffer)
 
         self.buffer = ''
 
+    def attach(self, buffer):
+        """
+        Read buffer until end (read() returns '') and sends it to self.logger and self.job_backend.
+
+        :param buffer: a buffer instance with block read() method
+        """
+        def reader():
+            while True:
+
+                # read() needs to block
+                buf = buffer.read(1)
+                if buf == '':
+                    return
+
+                self.write(buf.decode("utf-8"))
+
+        thread = Thread(target=reader)
+        thread.daemon = True
+        thread.start()
+
     def write(self, message):
-
-        # if message == '\n':
-        #     return
-
-        message = six.text_type(message)
-
-        # if not self.error:
-        #     message = self.get_line(message)
+        try:
+            message = six.text_type(message)
+        except:
+            pass
 
         try:
-            self.terminal.write(message)
+            self.logger.write(message)
 
             self.last_messages += message
-            if len(self.last_messages) > 500 * 1024:
-                self.last_messages = self.last_messages[-500 * 1024:]
+            if len(self.last_messages) > 20 * 1024:
+                self.last_messages = self.last_messages[-20 * 1024:]
 
             for char in message:
-                if '\b' == char:
+                if '\b' == char or '\r' == char:
                     self.buffer = self.buffer[:-1]
                 else:
                     self.buffer += char
@@ -77,5 +88,5 @@ class GeneralLogger(object):
             pass
 
         if not self.last_timer:
-            self.last_timer = Timer(1.0, self.send_to_buffer)
+            self.last_timer = Timer(1.0, self.send_buffer)
             self.last_timer.start()
\ No newline at end of file
