@@ -38,7 +38,7 @@ def upscale(image, ratio):
     """
     return upscaled image array
     Arguments:
-    image -- a (heigt, width , channels) numpy.ndarray
+    image -- a (H,W,C) numpy.ndarray
     ratio -- scaling factor (>1)
     """
     if not isinstance(image, np.ndarray):
@@ -50,7 +50,7 @@ def upscale(image, ratio):
     channels = image.shape[2]
     out = np.ndarray((height, width, channels), dtype=np.uint8)
     for x, y in np.ndindex((width, height)):
-        out[y, x] = image[math.floor(y / ratio), math.floor(x / ratio)]
+        out[y, x] = image[int(math.floor(y / ratio)), int(math.floor(x / ratio))]
     return out
 
 
@@ -274,6 +274,7 @@ def get_layer_vis_square(data,
                          min_img_dim=100,
                          max_width=1200,
                          channel_order='RGB',
+                         colormap='jet',
                          ):
     """
     Returns a vis_square for the given layer data
@@ -326,6 +327,68 @@ def get_layer_vis_square(data,
     else:
         raise RuntimeError('unrecognized data shape: %s' % (data.shape,))
 
+    return get_layer_vis_square_raw(data,
+                         allow_heatmap,
+                         normalize,
+                         min_img_dim,
+                         max_width,
+                         colormap,
+                         )
+
+def get_image_tales(images, colormap='jet', min_img_dim=100, max_width=1000):
+
+    padsize = 1
+    # convert to float since we're going to do some math
+    images = images.astype('float32')
+
+    images -= images.min()
+    if images.max() > 0:
+        images /= images.max()
+        images *= 255
+
+    if images.ndim == 3:
+        # they're grayscale - convert to a colormap
+        redmap, greenmap, bluemap = get_color_map(colormap)
+
+        red = np.interp(images * (len(redmap) - 1) / 255.0, range(len(redmap)), redmap)
+        green = np.interp(images * (len(greenmap) - 1) / 255.0, range(len(greenmap)), greenmap)
+        blue = np.interp(images * (len(bluemap) - 1) / 255.0, range(len(bluemap)), bluemap)
+
+        # Slap the channels back together
+        images = np.concatenate(
+            (red[..., np.newaxis], green[..., np.newaxis], blue[..., np.newaxis]), axis=3)
+        images = np.minimum(images, 255)
+        images = np.maximum(images, 0)
+
+    # convert back to uint8
+    images = images.astype('uint8')
+
+    # Compute the output image matrix dimensions
+    n = int(np.ceil(np.sqrt(images.shape[0])))
+    ny = n
+    nx = n
+    length = images.shape[0]
+    if n * (n - 1) >= length:
+        nx = n - 1
+
+    # Add padding between the images
+    padding = ((0, nx * ny - length), (0, padsize), (0, padsize)) + ((0, 0),) * (images.ndim - 3)
+    padded = np.pad(images, padding, mode='constant', constant_values=0)
+
+    # Tile the images beside each other
+    tiles = padded.reshape(
+        (ny, nx) + padded.shape[1:]).transpose((0, 2, 1, 3) + tuple(range(4, padded.ndim + 1)))
+    tiles = tiles.reshape((ny * tiles.shape[1], nx * tiles.shape[3]) + tiles.shape[4:])
+
+    return tiles
+
+def get_layer_vis_square_raw(data,
+                         allow_heatmap=True,
+                         normalize=True,
+                         min_img_dim=100,
+                         max_width=1200,
+                         colormap='jet',
+                         ):
     # chop off data so that it will fit within max_width
     padsize = 0
     width = data.shape[2]
@@ -345,6 +408,7 @@ def get_layer_vis_square(data,
     vis = vis_square(data,
                      padsize=padsize,
                      normalize=normalize,
+                     colormap=colormap
                      )
 
     # find minimum dimension and upscale if necessary
